/*
  
  Constants to define the behavior and/or customization of the
  module

  lem@cantv.net 19980809

  */

/* crypt() function to use. Comment to skip this function. */
#define STD_CRYPT fcrypt

/* crypt16() function to use. Comment to skip this function. */
/* #define EXT_CRYPT crypt16 */
